summaryrefslogtreecommitdiffstats
path: root/src/usr/diag
diff options
context:
space:
mode:
Diffstat (limited to 'src/usr/diag')
-rwxr-xr-xsrc/usr/diag/prdf/common/runtime/prdfCenMbaTdCtlr_rt.C4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/usr/diag/prdf/common/runtime/prdfCenMbaTdCtlr_rt.C b/src/usr/diag/prdf/common/runtime/prdfCenMbaTdCtlr_rt.C
index 65cb64da3..e69a128b1 100755
--- a/src/usr/diag/prdf/common/runtime/prdfCenMbaTdCtlr_rt.C
+++ b/src/usr/diag/prdf/common/runtime/prdfCenMbaTdCtlr_rt.C
@@ -2148,7 +2148,9 @@ int32_t CenMbaTdCtlr::handleCeEte_Tps( STEP_CODE_DATA_STRUCT & io_sc )
if ( !available )
{
- // Spares have been used. Make the error log predictive.
+ // Spares have been used. Callout the mark. Make the error log
+ // predictive.
+ CalloutUtil::calloutMark( iv_mbaTrgt, iv_rank, iv_mark, io_sc );
setTdSignature( io_sc, PRDFSIG_TpsCmAndSpare );
io_sc.service_data->setServiceCall();
}
OpenPOWER on IntegriCloud